@@ -32,19 +32,17 @@ class TestChangeSet(TestCase):
         }
 
     def test_changeset_for_history_that_does_not_have_first_insert(self):
-        tx_id = self.session.execute(
-            '''
-            INSERT INTO transaction_log (issued_at) VALUES (NOW())
-            RETURNING id
-            '''
-        ).fetchone()[0]
+        tx_log_class = self.Article.__versioned__['transaction_log']
+        tx_log = tx_log_class(issued_at=sa.func.now())
+        self.session.add(tx_log)
+        self.session.commit()
 
         self.session.execute(
             '''INSERT INTO article_history
             (id, transaction_id, name, content, operation_type)
             VALUES
             (1, %d, 'something', 'some content', 1)
-            ''' % tx_id
+            ''' % tx_log.id
         )
 
         assert self.session.query(self.ArticleHistory).first().changeset == {}
